@@ -1,3 +1,5 @@
+import uuid
+
 from cryptography import fernet
 from django.core.management import BaseCommand
 
@@ -6,4 +8,5 @@ class Command(BaseCommand):
     help = 'Command to generate a new Fernet key'
 
     def handle(self, *args, **options):  # pylint: disable=unused-argument
-        print(fernet.Fernet.generate_key().decode())
+        print('KEY:', fernet.Fernet.generate_key().decode())
+        print('HASH_SALT:', str(uuid.uuid4()).split('-')[0])
